from setuptools import setup, find_packages

setup(
    name='mltrainer-checker',
    version='0.15',
    description='A tool to validate machine learning models implemented on different machine learning platforms to ensure they are working correctly.',
    author='hiendang7613',
    author_email='dvhqnn1@gmail.com',
    url='https://github.com/hiendang7613/MLTrainerChecker',
    packages=find_packages(),
)
